__title__ = 'steelconnection'
__description__ = 'Simplify access to the Riverbed SteelConnect REST API.'
__url__ = 'https://github.com/grelleum/SteelConnection'
__version__ = '0.8.9'
__author__ = 'Greg Mueller'
__author_email__ = 'steelconnection@grelleum.com'
__license__ = 'MIT'
__copyright__ = 'Copyright 2018 Greg Mueller'
