from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import steelconnection.version

home = 'https://pypi.org/project/steelconnection/'

if __name__ == '__main__':
    print('SteelConnection version:', steelconnection.version.__version__)
    print('Documentation available at', home)
